==> haskell-keys-3.12.1-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-keys.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: keys
version: 3.12.1
id: keys-3.12.1-DvGlh5P1ixy6NHkMikNQwY
key: keys-3.12.1-DvGlh5P1ixy6NHkMikNQwY
license: BSD-3-Clause
copyright: Copyright (C) 2011-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/keys/
synopsis: Keyed functors and containers
description:
    This package provides a bunch of ad hoc classes for accessing parts of a container.
    .
    In practice this package is largely subsumed by the
    <https://hackage.haskell.org/package/lens lens package>,
    but it is maintained for now as it has much
    simpler dependencies.
category: Data Structures, Containers
abi: 5eed0e4c190138369fbdf43458a12287
exposed: True
exposed-modules:
    Data.Key
import-dirs: /usr/lib/ghc-8.4.3/site-local/keys-3.12.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/keys-3.12.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/keys-3.12.1
hs-libraries: HSkeys-3.12.1-DvGlh5P1ixy6NHkMikNQwY
depends:
    array-0.5.2.0 base-4.11.1.0 comonad-5.0.4-1KPVbJvpw3M67zUspVhW1b
    containers-0.5.11.0 free-5.1-9xpMc0UpVNABox4Ng4cLNH
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    semigroupoids-5.3.1-CUPD9rRErPJCB8rgcbyu7X
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
abi-depends: array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             comonad-5.0.4-1KPVbJvpw3M67zUspVhW1b=7d34015bc054afd76e5671409be5d152
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             free-5.1-9xpMc0UpVNABox4Ng4cLNH=32de3f2a39fdc35e10b869fccc17792d
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             semigroupoids-5.3.1-CUPD9rRErPJCB8rgcbyu7X=cdec372b94ffd1d13cacf4334456a765
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
haddock-interfaces: /usr/share/doc/haskell-keys/html/keys.haddock
haddock-html: /usr/share/doc/haskell-keys/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-keys-3.12.1-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-keys.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: keys
version: 3.12.1
id: keys-3.12.1-8qOAn4sZNQnHui49vvqEpR
key: keys-3.12.1-8qOAn4sZNQnHui49vvqEpR
license: BSD-3-Clause
copyright: Copyright (C) 2011-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/keys/
synopsis: Keyed functors and containers
description:
    This package provides a bunch of ad hoc classes for accessing parts of a container.
    .
    In practice this package is largely subsumed by the
    <https://hackage.haskell.org/package/lens lens package>,
    but it is maintained for now as it has much
    simpler dependencies.
category: Data Structures, Containers
abi: f31dc7523fcf0d7655221f489e0d4727
exposed: True
exposed-modules:
    Data.Key
import-dirs: /usr/lib/ghc-8.4.3/site-local/keys-3.12.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/keys-3.12.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/keys-3.12.1
hs-libraries: HSkeys-3.12.1-8qOAn4sZNQnHui49vvqEpR
depends:
    array-0.5.2.0 base-4.11.1.0 comonad-5.0.4-6BvCuhx7i312Moy5XX16V2
    containers-0.5.11.0 free-5.1-HT7N17Zwnuw79GRgcsQMzL
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    semigroupoids-5.3.1-8LPV17szXQVB81Uqgw1FRZ
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
abi-depends: array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             comonad-5.0.4-6BvCuhx7i312Moy5XX16V2=9c90e8f94411c9626a7e8a62a1f015de
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             free-5.1-HT7N17Zwnuw79GRgcsQMzL=61d01a0a1f0be0653955cf84b7f24de1
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             semigroupoids-5.3.1-8LPV17szXQVB81Uqgw1FRZ=fefe65a9667b054c22e0c4972c268b42
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
haddock-interfaces: /usr/share/doc/haskell-keys/html/keys.haddock
haddock-html: /usr/share/doc/haskell-keys/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
